==> apache-streampipes-0.93.0-source-release.zip: apache-streampipes-0.93.0/streampipes-data-explorer/src/test/java/org/apache/streampipes/dataexplorer/query/writer/item/TestCsvItemWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.dataexplorer.query.writer.item;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class TestCsvItemWriter extends TestItemWriter {

  private static final String ExpectedComma = "1668578077051,test,1";
  private static final String ExpectedSemicolon = "1668578077051;test;1";

  @Test
  public void testCsvItemWriterCommaSeparated() {
    var writer = new CsvItemWriter(",");

    String result = writer.createItem(row, columns);

    assertEquals(ExpectedComma, result);
  }

  @Test
  public void testCsvItemWriterSemicolonSeparated() {
    var writer = new CsvItemWriter(";");

    String result = writer.createItem(row, columns);

    assertEquals(ExpectedSemicolon, result);
  }
}

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-data-explorer/src/test/java/org/apache/streampipes/dataexplorer/query/writer/item/TestCsvItemWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.dataexplorer.query.writer.item;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class TestCsvItemWriter extends TestItemWriter {

  private static final String ExpectedComma = "1668578077051,test,1";
  private static final String ExpectedSemicolon = "1668578077051;test;1";

  @Test
  public void testCsvItemWriterCommaSeparated() {
    var writer = new CsvItemWriter(",");

    String result = writer.createItem(row, columns);

    assertEquals(ExpectedComma, result);
  }

  @Test
  public void testCsvItemWriterSemicolonSeparated() {
    var writer = new CsvItemWriter(";");

    String result = writer.createItem(row, columns);

    assertEquals(ExpectedSemicolon, result);
  }
}
